;;*****************************************************************************
;;*****************************************************************************
;;  FILENAME:   ADCINC12_1.asm
;;  Version: 5.0, Updated on 2003/08/28 at 13:26:44
;;  Generated by PSoC Designer ver 4.0 b865 : 27 August, 2003
;;
;;  DESCRIPTION: ADCINC12 12 bit incremental A/D converter User Module 
;;               software implementation file for 22/24/25/26/27xxx PSoC
;;               family of devices.
;;
;;  NOTE: User Module APIs conform to the fastcall convention for marshalling
;;        arguments and observe the associated "Registers are volatile" policy.
;;        This means it is the caller's responsibility to preserve any values
;;        in the X and A registers that are still needed after the API 
;;        function returns. Even though these registers may be preserved now,
;;        there is no guarantee they will be preserved in future releases.
;;-----------------------------------------------------------------------------
;;  Copyright (c) Cypress MicroSystems 2000-2003. All Rights Reserved.
;;*****************************************************************************
;;*****************************************************************************

include "ADCINC12_1.inc"
include "m8c.inc"

;-----------------------------------------------
;  Global Symbols
;-----------------------------------------------
export  ADCINC12_1_Start
export _ADCINC12_1_Start
export  ADCINC12_1_SetPower
export _ADCINC12_1_SetPower
export  ADCINC12_1_Stop
export _ADCINC12_1_Stop
export  ADCINC12_1_GetSamples
export _ADCINC12_1_GetSamples
export  ADCINC12_1_StopAD
export _ADCINC12_1_StopAD
export  ADCINC12_1_fIsData
export _ADCINC12_1_fIsData
export  ADCINC12_1_fIsDataAvailable
export _ADCINC12_1_fIsDataAvailable
export  ADCINC12_1_iGetData
export _ADCINC12_1_iGetData
export  ADCINC12_1_ClearFlag
export _ADCINC12_1_ClearFlag

;-----------------------------------------------
;  EQUATES
;-----------------------------------------------
LowByte:   equ 1
HighByte:  equ 0

AREA UserModules (ROM, REL)
.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME: ADCINC12_1_Start
;  FUNCTION NAME: ADCINC12_1_SetPower
;
;  DESCRIPTION:
;     Applies power setting to the module's analog PSoC block.
;
;-----------------------------------------------------------------------------
;
;  ARGUMENTS:
;    A  contains the power setting
;
;  RETURNS: none
;
;  SIDE EFFECTS:
;    REGISTERS ARE VOLATILE: THE A AND X REGISTERS MAY BE MODIFIED!
;
;  THEORY of OPERATION or PROCEDURE:
;
;-----------------------------------------------------------------------------
 ADCINC12_1_Start:
_ADCINC12_1_Start:
 ADCINC12_1_SetPower:
_ADCINC12_1_SetPower:
   push X                              ;save X
   mov  X,SP	                       ;X will point at next pushed value
   and  A,03h
   push A		               ;X points at copy of A
   mov  A,reg[ADCINC12_1_AtoDcr3]
   and  A,~03h                         ;clear power bits
   or   A,[ X ]
   mov  reg[ADCINC12_1_AtoDcr3],A
   pop  A
   pop  X
   ret
.ENDSECTION

.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME: ADCINC12_1_Stop
;
;  DESCRIPTION:
;    Removes power from the module's analog PSoC Block
;
;-----------------------------------------------------------------------------
;
;  ARGUMENTS: none
;
;  RETURNS: none
;
;  SIDE EFFECTS:
;    REGISTERS ARE VOLATILE: THE A AND X REGISTERS MAY BE MODIFIED!
;
;  THEORY of OPERATION or PROCEDURE:
;
;-----------------------------------------------------------------------------
 ADCINC12_1_Stop:
_ADCINC12_1_Stop:
   and reg[ADCINC12_1_AtoDcr3], ~03h
   ret
.ENDSECTION

.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME: ADCINC12_1_Get_Samples
;
;  DESCRIPTION:
;    Starts the A/D convertor and will place data is memory.  A flag
;    is set whenever a new data value is available.
;
;-----------------------------------------------------------------------------
;
;  ARGUMENTS:
;    A  passes the number of samples to be taken.  (0 is continous)
;
;  RETURNS:
;
;  SIDE EFFECTS:
;    REGISTERS ARE VOLATILE: THE A AND X REGISTERS MAY BE MODIFIED!
;
;  THEORY of OPERATION or PROCEDURE:
;
;-----------------------------------------------------------------------------
 ADCINC12_1_GetSamples:
_ADCINC12_1_GetSamples:
   mov [ADCINC12_1_bIncrC],A	                    ;number of samples
   or  reg[INT_MSK1],(ADCINC12_1_TimerMask | ADCINC12_1_CounterMask )
                                                 ;Enable both interrupts
   mov [ADCINC12_1_cTimerU],1                    ;Force the Timer to do one cycle of rest
IF ADCINC12_1_NoAZ
   or  reg[ADCINC12_1_AtoDcr2],20h               ;force the Integrator into reset
ENDIF
   or  reg[ADCINC12_1_AtoDcr3],10h
   mov [ADCINC12_1_cCounterU],(-(1<<(ADCINC12_1_NUMBITS - 7)));Initialize Counter
   mov reg[ADCINC12_1_TimerDR1],ffh
   mov reg[ADCINC12_1_CounterDR1],ffh
   mov reg[ADCINC12_1_TimerCR0],01h              ;enable the Timer
   mov [ADCINC12_1_fIncr],00h                    ;A/D Data Ready Flag is reset
   ret
.ENDSECTION

.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME: ADCINC12_1_StopAD
;
;  DESCRIPTION:
;    Completely shuts down the A/D is an orderly manner.  Both the
;    Timer and COunter interrupts are disabled.
;
;-----------------------------------------------------------------------------
;
;  ARGUMENTS:  none
;
;  RETURNS:  none
;
;  SIDE EFFECTS:
;    REGISTERS ARE VOLATILE: THE A AND X REGISTERS MAY BE MODIFIED!
;
;  THEORY of OPERATION or PROCEDURE:
;
;-----------------------------------------------------------------------------
 ADCINC12_1_StopAD:
_ADCINC12_1_StopAD:
   mov reg[ADCINC12_1_TimerCR0],00h              ;disable the Timer
   mov reg[ADCINC12_1_CounterCR0],00h            ;disable the Counter
   nop
   nop
   ;Disable both interrupts
   M8C_DisableIntMask INT_MSK1, (ADCINC12_1_TimerMask | ADCINC12_1_CounterMask )
IF ADCINC12_1_NoAZ
   or  reg[ADCINC12_1_AtoDcr2],20h               ;reset Integrator
ENDIF
   or  reg[ADCINC12_1_AtoDcr3],10h
   ret
.ENDSECTION

.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME: ADCINC12_1_fIsDataAvailable
;
;  DESCRIPTION:
;    This function returns a non-zero value when the ADC conversion
;    is complete.
;
;-----------------------------------------------------------------------------
;
;  ARGUMENTS: none
;
;  RETURNS:
;    A returns conversion status  A  = 0, conversion not complete
;                                 A != 0, Data available
;
;  SIDE EFFECTS:
;    REGISTERS ARE VOLATILE: THE A AND X REGISTERS MAY BE MODIFIED!
;
;  THEORY of OPERATION or PROCEDURE:
;
;-----------------------------------------------------------------------------
 ADCINC12_1_fIsData:
_ADCINC12_1_fIsData:
 ADCINC12_1_fIsDataAvailable:
_ADCINC12_1_fIsDataAvailable:
   mov A,[ADCINC12_1_fIncr]
   ret
.ENDSECTION

.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME: ADCINC12_1_iGetData
;
;  DESCRIPTION:
;    Returns the data from the A/D.  Does not check if data is available.
;    Is set whenever a new data value is available.
;
;-----------------------------------------------------------------------------
;
;  ARGUMENTS: none
;
;  RETURNS:
;    Returns 16 bit ADC result  X contains MSB
;                               A contains LSB
;
;  SIDE EFFECTS:
;    REGISTERS ARE VOLATILE: THE A AND X REGISTERS MAY BE MODIFIED!
;
;  THEORY of OPERATION or PROCEDURE:
;
;-----------------------------------------------------------------------------
 ADCINC12_1_iGetData:
_ADCINC12_1_iGetData:
   mov X,[(ADCINC12_1_iIncr + HighByte)]
   mov A,[(ADCINC12_1_iIncr + LowByte)]
   ret
.ENDSECTION

.SECTION
;-----------------------------------------------------------------------------
;  FUNCTION NAME: ADCINC12_1_ClearFlag
;
;  DESCRIPTION:
;    Clears data ready flag.
;
;-----------------------------------------------------------------------------
;
;  ARGUMENTS: none
;
;  RETURNS:  none
;
;  SIDE EFFECTS:
;    REGISTERS ARE VOLATILE: THE A AND X REGISTERS MAY BE MODIFIED!
;
;  THEORY of OPERATION or PROCEDURE:
;
;-----------------------------------------------------------------------------
 ADCINC12_1_ClearFlag:
_ADCINC12_1_ClearFlag:
   mov [ADCINC12_1_fIncr],00h
   ret
.ENDSECTION

; End of File ADCINC12_1.asm
